@@ -5,12 +5,14 @@ extern "C" {
   #include <string.h>
   #include "cl_min.h"
   #include <pcre.h>
-  #include "globals.h"
-  #include "context_descriptor.h"
-  #include "_options.h"
-  #include "cqp.h"
-  #include "corpmanag.h"
+/*  #include "globals.h" */
+/*  #include "context_descriptor.h" */
+/*  #include "_options.h" */
+/*  #include "cqp.h" */
+/*  #include "corpmanag.h" */
   #include "server.h"
+  #include "globalvars.h"
+  #include "env.h"
 }
 
 #include <Rcpp.h>
@@ -23,7 +25,6 @@ using namespace Rcpp;
 
 int cqp_initialization_status = 0;
 
-
 Attribute* make_s_attribute(SEXP corpus, SEXP s_attribute, SEXP registry){
   
   char* reg_dir = strdup(Rcpp::as<std::string>(registry).c_str());
@@ -393,9 +394,9 @@ SEXP cqp_query(SEXP corpus, SEXP subcorpus, SEXP query){
     full_child = combine_subcorpus_spec(mother, child); /* c is the 'physical' part of the mother corpus */
 
     childcl = cqi_find_corpus(full_child);
-    /* if ((childcl) == NULL) {
-    printf("subcorpus not found\n");
-    } */
+    if ((childcl) == NULL) {
+      Rprintf("subcorpus not found\n");
+    } 
   }
 
   
